==> ease-p2-v0.5.0.zip: org/eclipse/ease/lang/python/debugger/model/PythonDebugTarget.java <==
/*******************************************************************************
 * Copyright (c) 2013 Martin Kloesch and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Christian Pontesegger - initial API
 *     Martin Kloesch - implementation
 *******************************************************************************/
package org.eclipse.ease.lang.python.debugger.model;

import org.eclipse.debug.core.DebugException;
import org.eclipse.debug.core.DebugPlugin;
import org.eclipse.debug.core.ILaunch;
import org.eclipse.debug.core.model.IBreakpoint;
import org.eclipse.ease.Script;
import org.eclipse.ease.debugging.ScriptDebugTarget;

/**
 * ScriptDebugTarget for communication between Eclipse framework and Python debugger.
 */
public class PythonDebugTarget extends ScriptDebugTarget {
	private static final String pyBreakpointType = PythonDebugModelPresentation.ID;

	/**
	 * Constructor for now only calls super constructor.
	 *
	 * @param launch
	 * @param suspendOnStartup
	 * @param suspendOnScriptLoad
	 * @param showDynamicCode
	 */
	public PythonDebugTarget(final ILaunch launch, final boolean suspendOnStartup, final boolean suspendOnScriptLoad, boolean showDynamicCode) {
		super(launch, suspendOnStartup, suspendOnScriptLoad, showDynamicCode);
	}

	@Override
	public String getName() throws DebugException {
		return "EASE Python Debugger";
	}

	// ************************************************************
	// IEventProcessor
	// ************************************************************

	/**
	 * Getter methods for all matching breakpoints in given script.
	 *
	 * Currently EASE Python Debugger uses PyDev breakpoints, this could change though.
	 */
	@Override
	protected IBreakpoint[] getBreakpoints(final Script script) {
		return DebugPlugin.getDefault().getBreakpointManager().getBreakpoints(pyBreakpointType);
	}

	@Override
	public boolean supportsBreakpoint(final IBreakpoint breakpoint) {
		return true;
	}

	@Override
	public String getModelIdentifier() {
		return "org.eclipse.ease.debugModelPresentation.python";
	}
}

==> ease-p2-v0.6.0.zip: org/eclipse/ease/lang/python/debugger/model/PythonDebugTarget.java <==
/*******************************************************************************
 * Copyright (c) 2013 Martin Kloesch and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Christian Pontesegger - initial API
 *     Martin Kloesch - implementation
 *******************************************************************************/
package org.eclipse.ease.lang.python.debugger.model;

import org.eclipse.debug.core.DebugPlugin;
import org.eclipse.debug.core.ILaunch;
import org.eclipse.debug.core.model.IBreakpoint;
import org.eclipse.ease.Script;
import org.eclipse.ease.debugging.model.EaseDebugTarget;

/**
 * ScriptDebugTarget for communication between Eclipse framework and Python debugger.
 */
public class PythonDebugTarget extends EaseDebugTarget {
	private static final String pyBreakpointType = PythonDebugModelPresentation.ID;

	/**
	 * Constructor for now only calls super constructor.
	 *
	 * @param launch
	 * @param suspendOnStartup
	 * @param suspendOnScriptLoad
	 * @param showDynamicCode
	 */
	public PythonDebugTarget(final ILaunch launch, final boolean suspendOnStartup, final boolean suspendOnScriptLoad, boolean showDynamicCode) {
		super(launch, suspendOnStartup, suspendOnScriptLoad, showDynamicCode);
	}

	@Override
	public String getName() {
		return "EASE Python Debugger";
	}

	// ************************************************************
	// IEventProcessor
	// ************************************************************

	/**
	 * Getter methods for all matching breakpoints in given script.
	 *
	 * Currently EASE Python Debugger uses PyDev breakpoints, this could change though.
	 */
	@Override
	protected IBreakpoint[] getBreakpoints(final Script script) {
		return DebugPlugin.getDefault().getBreakpointManager().getBreakpoints(pyBreakpointType);
	}

	@Override
	public boolean supportsBreakpoint(final IBreakpoint breakpoint) {
		return true;
	}

	@Override
	public String getModelIdentifier() {
		return "org.eclipse.ease.debugModelPresentation.python";
	}
}
